.. currentmodule:: sardana.macroserver.macro

.. _sardana-devel-macro-input-examples:

====================
Macro input examples
====================

This chapter consists of a series of examples demonstrating how to ask for user
input inside macros.

A tutorial on macro input parameter can be found :ref:`here <sardana-macro-input>`.
The :term:`API` documentation: :meth:`~Macro.input`

.. literalinclude:: ../../../../src/sardana/macroserver/macros/examples/user_input.py
   :language: python
   :linenos:
